[**高度な設定**](./introduction.md) > **言語コード** _(current)_

---

#### Google

ソース <https://developers.google.com/admin-sdk/directory/v1/languages?hl=zh-cn>, GPT-4o によって整理。

| 中国語でのラベル | Label | `Language Code` |
| --- | --- | --- |
| アムハラ語 | Amharic | `am` |
| アラビア語 | Arabic | `ar` |
| バスク語 | Basque | `eu` |
| ベンガル語 | Bengali | `bn` |
| 英語（イギリス） | English (UK) | `en-GB` |
| ポルトガル語（ブラジル） | Portuguese (Brazil) | `pt-BR` |
| ブルガリア語 | Bulgarian | `bg` |
| カタルーニャ語 | Catalan | `ca` |
| チェロキー語 | Cherokee | `chr` |
| クロアチア語 | Croatian | `hr` |
| チェコ語 | Czech | `cs` |
| デンマーク語 | Danish | `da` |
| オランダ語 | Dutch | `nl` |
| 英語（アメリカ） | English (US) | `en` |
| エストニア語 | Estonian | `et` |
| フィリピン語 | Filipino | `fil` |
| フィンランド語 | Finnish | `fi` |
| フランス語 | French | `fr` |
| ドイツ語 | German | `de` |
| ギリシャ語 | Greek | `el` |
| グジャラート語 | Gujarati | `gu` |
| ヘブライ語 | Hebrew | `iw` |
| ヒンディー語 | Hindi | `hi` |
| ハンガリー語 | Hungarian | `hu` |
| アイスランド語 | Icelandic | `is` |
| インドネシア語 | Indonesian | `id` |
| イタリア語 | Italian | `it` |
| 日本語 | Japanese | `ja` |
| カンナダ語 | Kannada | `kn` |
| 韓国語 | Korean | `ko` |
| ラトビア語 | Latvian | `lv` |
| リトアニア語 | Lithuanian | `lt` |
| マレー語 | Malay | `ms` |
| マラヤーラム語 | Malayalam | `ml` |
| マラーティー語 | Marathi | `mr` |
| ノルウェー語 | Norwegian | `no` |
| ポーランド語 | Polish | `pl` |
| ポルトガル語（ポルトガル） | Portuguese (Portugal) | `pt-PT` |
| ルーマニア語 | Romanian | `ro` |
| ロシア語 | Russian | `ru` |
| セルビア語 | Serbian | `sr` |
| 中国語（中国） | Chinese (PRC) | `zh-CN` |
| スロバキア語 | Slovak | `sk` |
| スロベニア語 | Slovenian | `sl` |
| スペイン語 | Spanish | `es` |
| スワヒリ語 | Swahili | `sw` |
| スウェーデン語 | Swedish | `sv` |
| タミル語 | Tamil | `ta` |
| テルグ語 | Telugu | `te` |
| タイ語 | Thai | `th` |
| 中国語（台湾） | Chinese (Taiwan) | `zh-TW` |
| トルコ語 | Turkish | `tr` |
| ウルドゥー語 | Urdu | `ur` |
| ウクライナ語 | Ukrainian | `uk` |
| ベトナム語 | Vietnamese | `vi` |
| ウェールズ語 | Welsh | `cy` |


#### DeepL
ソース <https://developers.deepl.com/docs/resources/supported-languages>, GPT-4o によって整理。

| 中国語でのラベル | ラベル | `Language Code`| サポート |
| --- | --- | --- | --- |
| アラビア語 | Arabic | `AR` | `source`, `target` |
| ブルガリア語 | Bulgarian | `BG` | `source`, `target` |
| チェコ語 | Czech | `CS` | `source`, `target` |
| デンマーク語 | Danish | `DA` | `source`, `target` |
| ドイツ語 | German | `DE` | `source`, `target` |
| ギリシャ語 | Greek | `EL` | `source`, `target` |
| 英語 | English | `EN` | `source`, `target` |
| 英語（イギリス） | English (British) | `EN-GB` | `target` |
| 英語（アメリカ） | English (American) | `EN-US` | `target` |
| スペイン語 | Spanish | `ES` | `source`, `target` |
| エストニア語 | Estonian | `ET` | `source`, `target` |
| フィンランド語 | Finnish | `FI` | `source`, `target` |
| フランス語 | French | `FR` | `source`, `target` |
| ハンガリー語 | Hungarian | `HU` | `source`, `target` |
| インドネシア語 | Indonesian | `ID` | `source`, `target` |
| イタリア語 | Italian | `IT` | `source`, `target` |
| 日本語 | Japanese | `JA` | `source`, `target` |
| 韓国語 | Korean | `KO` | `source`, `target` |
| リトアニア語 | Lithuanian | `LT` | `source`, `target` |
| ラトビア語 | Latvian | `LV` | `source`, `target` |
| ノルウェー語（ブークモール） | Norwegian Bokmål | `NB` | `source`, `target` |
| オランダ語 | Dutch | `NL` | `source`, `target` |
| ポーランド語 | Polish | `PL` | `source`, `target` |
| ポルトガル語 | Portuguese | `PT` | `source`, `target` |
| ポルトガル語（ブラジル） | Portuguese (Brazilian) | `PT-BR` | `target` |
| ポルトガル語（ヨーロッパ） | Portuguese (European) | `PT-PT` | `target` |
| ルーマニア語 | Romanian | `RO` | `source`, `target` |
| ロシア語 | Russian | `RU` | `source`, `target` |
| スロバキア語 | Slovak | `SK` | `source`, `target` |
| スロベニア語 | Slovenian | `SL` | `source`, `target` |
| スウェーデン語 | Swedish | `SV` | `source`, `target` |
| トルコ語 | Turkish | `TR` | `source`, `target` |
| ウクライナ語 | Ukrainian | `UK` | `source`, `target` |
| 日本語 | Japanese | `JA` | `source`, `target` |
| 中国語（簡体字） | Chinese (Simplified) | `ZH-HANS` | `target` |
| 中国語（繁体） | Chinese (Traditional) | `ZH-HANT` | `target` |

<div align="right"> 
<h6><small>このページの一部のコンテンツは GPT によって翻訳されており、エラーが含まれている可能性があります。</small></h6>